#!/bin/sh
# script to generate tarball
which git > /dev/null 2>&1
if [ $? -gt 0 ]; then
  echo "No git found. Install git"
  exit 1
fi
which git-archive-all > /dev/null 2>&1
if [ $? -gt 0 ]; then
  echo "No git-archive-all found. Install git-archive-all"
  exit 1
fi
set -e
giturl='https://github.com/wxWidgets/wxWidgets.git'
cwd=$(pwd)
tmpdir=$(mktemp -d)
if [ -n "$1" ]
then
    version="$1"
else
    version='master'
fi
cd $tmpdir
git clone "$giturl"
cd wxWidgets
git checkout $version
git submodule update --init .
DATE=$(git log -1 --format="%cd" --date=short | sed 's|-||g')
git-archive-all --force-submodules --prefix=wxWidgets-${DATE}/ wxWidgets-${DATE}.tar.bz2
if [[ -d "${cwd%SOURCES*}/SOURCES" ]]; then
  cp -af wxWidgets-${DATE}.tar.bz2 "${cwd%SOURCES*}/SOURCES"
  echo "Copied wxWidgets-${DATE}.tar.bz2 to ${cwd%SOURCES*}/SOURCES/wxWidgets-${DATE}.tar.bz2"
else
  cp -af wxWidgets-${DATE}.tar.bz2 "$cwd"
  echo "Copied wxWidgets-${DATE}.tar.bz2 to ${cwd}/wxWidgets-${DATE}.tar.bz2"
fi

cd "$cwd"
rm -Rf "$tmpdir"
