# bcond_with gtk3    = gtk2
# bcond_without gtk3 = gtk3
%bcond_without gtk3

# build with/without 2.8 compatibility
%bcond_without compat28

# build with/without wxGLCanvas Wayland/EGL back-end
%bcond_with glcanvasegl

# filter out autogenerated reqs from docs
%global __requires_exclude_from %{?__requires_exclude_from:%__requires_exclude_from|}^%{_docdir}

%define gtkver %{?with_gtk3:3}%{!?with_gtk3:2}

%define uname           wxWidgets
%define oname           wxgtk

%define version         3.2.7
#define gdate           20210325
%define rel             1

#%%define major           %%(echo %%{version} | cut -d. -f3)
%define major		0
%define api             %(echo %{version} | cut -d. -f1,2)
%define libnameudev     %mklibname wxgtku %{api} -d

%define apind		%(echo %{api} |tr -d .)

Summary:        GTK+ port of the wxWidgets library
Name:           wxgtk
Version:        %{version}
Release:        %mkrel %{?gdate:0.git%gdate.}%{rel}
License:        wxWidgets Library Licence
Group:          System/Libraries
URL:            https://www.wxwidgets.org/
Source0:        https://github.com/wxWidgets/wxWidgets/releases/download/v%{version}/%{uname}-%{?gdate}%{!?gdate:%version}.tar.bz2
Source1:        gettarball.sh
# Mageia patches
Patch500:       wxWidgets-3.1.4-fix-linking.patch
Patch501:       wxWidgets-2.9.5-multiarch-includes.patch
# Originally from Gentoo
Patch600:       wxWidgets-3.1.6-collision.patch
# Originally from Fedora
Patch700:       wxWidgets-3.1.6-abicheck.patch
BuildRequires:  bakefile
BuildRequires:  git-core
BuildRequires:  pcre2-devel
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(liblzma)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(expat)
BuildRequires:  pkgconfig(cppunit)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glu)
%if %{with gtk3} && %{with glcanvasegl}
BuildRequires:  pkgconfig(egl) >= 1.5
BuildRequires:  pkgconfig(wayland-egl)
%endif
BuildRequires:  pkgconfig(gspell-1)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
%if %{with gtk3}
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(webkit2gtk-4.1)
%else
BuildRequires:  pkgconfig(gtk+-2.0)
%endif
BuildRequires:  pkgconfig(libmspack)
BuildRequires:  pkgconfig(libnotify) >= 0.7
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)

%description
wxWidgets is a free C++ library for cross-platform GUI development.
With wxWidgets, you can create applications for different GUIs (GTK+,
Motif/LessTif, MS Windows, Mac) from the same source code.

%package -n %{name}%{api}
Summary:        GTK+ port of the wxWidgets library
Group:          System/Libraries

%description -n %{name}%{api}
wxWidgets is a free C++ library for cross-platform GUI development.
With wxWidgets, you can create applications for different GUIs (GTK+,
Motif/LessTif, MS Windows, Mac) from the same source code.

%global wxlibs wx_baseu \\\
wx_baseu_net \\\
wx_baseu_xml \\\
wx_gtk%{gtkver}u_adv \\\
wx_gtk%{gtkver}u_aui \\\
wx_gtk%{gtkver}u_core \\\
wx_gtk%{gtkver}u_gl \\\
wx_gtk%{gtkver}u_html \\\
wx_gtk%{gtkver}u_media \\\
wx_gtk%{gtkver}u_propgrid \\\
wx_gtk%{gtkver}u_qa \\\
wx_gtk%{gtkver}u_ribbon \\\
wx_gtk%{gtkver}u_richtext \\\
wx_gtk%{gtkver}u_stc \\\
wx_gtk%{gtkver}u_xrc

%if %{with gtk3}
%global wxlibs %{wxlibs} wx_gtk%{gtkver}u_webview
%endif

%{expand:%(for lib in %{wxlibs}; do cat << EOF
%%global libname$lib %%mklibname $lib %{api} %{major}
%%package -n %%{libname$lib}
Summary:        wxGTK $lib shared library
Group:          System/Libraries
Requires:       %{oname}%{api} >= %{version}-%{release}
EOF
done)}

%{expand:%(for lib in %{wxlibs}; do cat << EOF
%%description -n %%{libname$lib}
This package contains the library needed to run programs dynamically
linked with the wxGTK.
EOF
done)}

%{expand:%(for lib in %{wxlibs}; do cat << EOF
%%files -n %%{libname$lib}
%{_libdir}/lib$lib-%{api}.so.%{major}{,.*}
%if "$lib" == "wx_gtk%{gtkver}u_webview"
%if %{with gtk3}
%dir %{_libdir}/wx/%{api}/web-extensions/
%{_libdir}/wx/%{api}/web-extensions/webkit2_extu-%{api}.so
%endif
%endif
EOF
done)}

%package -n %{libnameudev}
Summary:        Header files and development documentation for wxGTK - unicode
Group:          Development/C++
Requires:	%{expand:%(for lib in %{wxlibs}; do echo -n "%%{libname$lib} = %{version}-%{release} "; done)}
Provides:       libwxgtku%{api}-devel = %{version}-%{release}
Provides:       wxgtku%{api}-devel = %{version}-%{release}
Provides:       wxgtk%{api}-devel = %{version}-%{release}
Provides:       libwxgtk%{api}-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       wxGTK3-devel = %{version}-%{release}
Requires(post):         update-alternatives
Requires(postun):       update-alternatives

%description -n %{libnameudev}
Header files for the unicode enabled version of wxGTK, the GTK+ port of
the wxWidgets library.

%prep
%autosetup -n %{uname}-%{?gdate}%{!?gdate:%version} -Sgit

# fix plugin dir for 64-bit
sed -i -e 's|/lib|/%{_lib}|' src/unix/stdpaths.cpp

# build against webkit2gtk-4.1
sed -i -e 's/webkit2gtk-4.0/webkit2gtk-4.1/g' configure.in

%build
aclocal --force -I$PWD/build/aclocal
autoconf -f
libtoolize --copy --force
# --disable-optimise prevents our $RPM_OPT_FLAGS being overridden
# (see OPTIMISE in configure).
# this code dereferences type-punned pointers like there's no tomorrow.
CFLAGS="%{optflags} -fno-strict-aliasing"
CXXFLAGS="%{optflags} -fno-strict-aliasing"

%configure \
        --with-expat=sys \
        --with-gtk=%{gtkver} \
        --with-libjpeg=sys \
        --with-liblzma \
        --with-libmspack \
        --with-libpng=sys \
        --with-libtiff=sys \
        --with-opengl \
        --with-regex=sys \
        --with-sdl \
        --with-zlib=sys \
        --enable-calendar \
        --enable-catch_segvs \
        %{?with_compat28:--enable-compat28} \
        --enable-controls \
        --enable-dataviewctrl \
        --enable-dirdlg \
        %{!?with_glcanvasegl:--disable-glcanvasegl} \
        --enable-graphics_ctx \
        --enable-grid \
        --enable-intl \
        --enable-ipv6 \
        --enable-mediactrl \
        --enable-msgdlg \
        --enable-numberdlg \
        --disable-optimise \
        --enable-permissive \
        --disable-rpath \
        --enable-splash \
        --enable-textdlg \
	EGREP='grep -E'

%make_build
# Why isn't this this part of the main build? Need to investigate.
%make_build -C locale allmo

#gw prepare samples
pushd demos
        make clean
        rm -f makefile* demos.bkl
popd

pushd samples
        make clean
        rm -f makefile* samples.bkl
popd

find demos samples -name Makefile|xargs perl -pi -e 's^CXXC =.*^CXXC=\$(CXX) `wx-config --cflags`^'
find demos samples -name Makefile|xargs perl -pi -e 's^EXTRALIBS =.*^EXTRALIBS=^'
find demos samples -name Makefile|xargs perl -pi -e 's^SAMPLES_RPATH_FLAG =.*^SAMPLES_RPATH_FLAG=^'

%install
%make_install

# dummy translation file
find %{buildroot} -name "wxmsw.mo" -delete

%find_lang wxstd-%{api}

%post -n %{libnameudev}
%{_sbindir}/update-alternatives \
        --install %{_bindir}/wx-config wx-config %{_bindir}/wx-config-%{api} 40 \
	--slave %{_bindir}/wxrc wxrc %{_bindir}/wxrc-%{api}

%postun -n %{libnameudev}
if [ $1 -eq 0 ]; then
%{_sbindir}/update-alternatives \
        --remove wx-config %{_bindir}/wx-config-%{api}
fi

%files -n %{name}%{api} -f wxstd-%{api}.lang
%doc README.md

%files -n %{libnameudev}
%doc samples/ docs/ demos/
%ghost %{_bindir}/wx-config
%ghost %{_bindir}/wxrc
%{_bindir}/wx-config-%{api}
%{_bindir}/wxrc-%{api}
%{_includedir}/wx-%{api}/
%dir %{_libdir}/wx/
%dir %{_libdir}/wx/include/
%dir %{_libdir}/wx/include/gtk%{gtkver}-unicode-%{api}/
%dir %{_libdir}/wx/include/gtk%{gtkver}-unicode-%{api}/wx/
%dir %{_libdir}/wx/config
%{_libdir}/wx/config/gtk%{gtkver}-unicode-%{api}
%{_libdir}/wx/include/gtk%{gtkver}-unicode-%{api}/wx/setup.h
%{_libdir}/libwx_baseu-%{api}.so
%{_libdir}/libwx_baseu_net-%{api}.so
%{_libdir}/libwx_baseu_xml-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_adv-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_aui-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_core-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_gl-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_html-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_media-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_propgrid-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_qa-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_ribbon-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_richtext-%{api}.so
%{_libdir}/libwx_gtk%{gtkver}u_stc-%{api}.so
%if %{with gtk3}
%{_libdir}/libwx_gtk%{gtkver}u_webview-%{api}.so
%endif
%{_libdir}/libwx_gtk%{gtkver}u_xrc-%{api}.so
%{_datadir}/bakefile/presets/wx*
%{_datadir}/aclocal/wxwin%{apind}.m4


%changelog
* Sat Mar 22 2025 daviddavid <daviddavid> 3.2.7-1.mga10
+ Revision: 2168374
- new version: 3.2.7

* Thu Sep 19 2024 daviddavid <daviddavid> 3.2.6-2.mga10
+ Revision: 2099060
- rebuild for new gspell 1.14.0

* Mon Sep 09 2024 wally <wally> 3.2.6-1.mga10
+ Revision: 2094742
- new version 3.2.6

* Mon May 20 2024 wally <wally> 3.2.5-1.mga10
+ Revision: 2065261
- new version 3.2.5

* Mon May 20 2024 daviddavid <daviddavid> 3.2.4-2.mga10
+ Revision: 2065113
- rebuild for i686

* Sat Nov 18 2023 wally <wally> 3.2.4-1.mga10
+ Revision: 2007462
- new version 3.2.4

* Wed Oct 11 2023 wally <wally> 3.2.3-1.mga10
+ Revision: 1994700
- new version 3.2.3

* Sun Sep 10 2023 wally <wally> 3.2.2.1-1.mga10
+ Revision: 1985776
- new version 3.2.2.1

* Mon Dec 12 2022 ns80 <ns80> 3.2.1-3.mga9
+ Revision: 1921151
- rebuild for new libtiff

* Mon Sep 19 2022 wally <wally> 3.2.1-2.mga9
+ Revision: 1890630
- build against webkit2gtk-4.1

* Sun Sep 11 2022 wally <wally> 3.2.1-1.mga9
+ Revision: 1887233
- new version 3.2.1

* Thu Jul 14 2022 wally <wally> 3.2.0-2.mga9
+ Revision: 1868926
- increase update-alternatives priority for wx-config

* Thu Jul 14 2022 wally <wally> 3.2.0-1.mga9
+ Revision: 1868924
- new version 3.2.0

* Sun Jun 12 2022 wally <wally> 3.1.7-1.mga9
+ Revision: 1864013
- new version 3.1.7
- new lib major 7
- provide wxGTK3-devel

* Thu Apr 14 2022 wally <wally> 3.1.6-2.mga9
+ Revision: 1849760
- filter out autogenerated reqs from docs

* Thu Apr 14 2022 wally <wally> 3.1.6-1.mga9
+ Revision: 1849638
- new version 3.1.6
- new lib major 6
- build with system pcre2
- enable liblzma and gspell support

* Sun Apr 03 2022 umeabot <umeabot> 3.1.5-6.mga9
+ Revision: 1841755
- Mageia 9 Mass Rebuild

* Sat Jan 15 2022 wally <wally> 3.1.5-5.mga9
+ Revision: 1768472
- add upstream patches to make wxSizer::SetSizeHints() work again

* Tue Jan 04 2022 wally <wally> 3.1.5-4.mga9
+ Revision: 1766824
- disable EGL support again

* Mon Jan 03 2022 wally <wally> 3.1.5-3.mga9
+ Revision: 1766403
- enable wxGLCanvas Wayland/EGL backend
- drop old obsoletes
- remove webkit1 remains from .spec

* Wed Apr 28 2021 daviddavid <daviddavid> 3.1.5-2.mga9
+ Revision: 1720340
- disable glcanvasegl support for now to allow kicad to work (mga#28352)
  * https://gitlab.com/kicad/code/kicad/-/issues/8320

* Thu Apr 15 2021 daviddavid <daviddavid> 3.1.5-1.mga9
+ Revision: 1715845
- new version: 3.1.5 (final)

* Sat Mar 27 2021 wally <wally> 3.1.5-0.git20210325.1.mga9
+ Revision: 1711095
- new git snapshot 20210325

* Thu Mar 18 2021 daviddavid <daviddavid> 3.1.5-0.git20201230.2.mga9
+ Revision: 1704218
- rebuild against new glibc

* Fri Jan 01 2021 wally <wally> 3.1.5-0.git20201230.1.mga8
+ Revision: 1667679
- update to latest pre 3.1.5 git snapshot

* Sun Aug 16 2020 wally <wally> 3.1.4-1.mga8
+ Revision: 1614310
- new version 3.1.4
+ daviddavid <daviddavid>
- replace deprecated %%configure2_5x

* Mon Feb 17 2020 umeabot <umeabot> 3.1.3-2.mga8
+ Revision: 1537786
- Mageia 8 Mass Rebuild

* Sun Nov 10 2019 wally <wally> 3.1.3-1.mga8
+ Revision: 1459086
- new version 3.1.3
- new lib major 3

* Sat Oct 12 2019 wally <wally> 3.1.2-5.mga8
+ Revision: 1452371
- disable python bytecompile outside python dirs
- add api to pkg name

* Mon Jul 15 2019 wally <wally> 3.1.2-4.mga8
+ Revision: 1421738
- increase alternatives priority for wx-config

* Mon Jul 15 2019 wally <wally> 3.1.2-3.mga8
+ Revision: 1421658
- install versioned .m4 file
- own wx-config and wxrc handled by alternatives system

* Mon Jul 08 2019 wally <wally> 3.1.2-2.mga8
+ Revision: 1419502
- enable wxgtk 2.8 compatibility

* Sat Jun 29 2019 wally <wally> 3.1.2-1.mga8
+ Revision: 1415411
- new version 3.1.2
- new api 3.1
- new major 2
- switch to gtk3
- drop old/unneeded obsoletes and conflicts
- drop multiarch support
- update alternatives support

* Mon Mar 04 2019 wally <wally> 3.0.4-7.mga7
+ Revision: 1371473
- build with sdl2
- obsolete renamed gl library

* Mon Mar 04 2019 tv <tv> 3.0.4-6.mga7
+ Revision: 1371434
- fix upgrade

* Sun Mar 03 2019 wally <wally> 3.0.4-5.mga7
+ Revision: 1371205
- split out libs into their own pkgs

* Tue Feb 26 2019 wally <wally> 3.0.4-4.mga7
+ Revision: 1370258
- build without webkit1

* Sun Sep 23 2018 umeabot <umeabot> 3.0.4-3.mga7
+ Revision: 1301724
- Mageia 7 Mass Rebuild

* Mon Jun 18 2018 wally <wally> 3.0.4-2.mga7
+ Revision: 1237856
- add patch from Fedora to not abort when ABI check fails (mga#23192)

* Wed Mar 28 2018 daviddavid <daviddavid> 3.0.4-1.mga7
+ Revision: 1212964
- new version: 3.0.4
- rename and rediff collision patch
- enable ipv6 support

* Sat Oct 07 2017 cjw <cjw> 3.0.3.1-2.mga7
+ Revision: 1169955
- drop unused buildrequires: pkgconfig(libgnomeprintui-2.2)

* Sat Jun 03 2017 akien <akien> 3.0.3.1-1.mga6
+ Revision: 1106032
- Version 3.0.3.1
- Rediff P2 and drop upstreamed P3

* Sat Feb 18 2017 cjw <cjw> 3.0.2-11.mga6
+ Revision: 1086672
- package wxwin.m4 to fix build of spek

* Sat Feb 18 2017 cjw <cjw> 3.0.2-10.mga6
+ Revision: 1086660
- patch3: build with gstreamer1.0 instead of gstreamer0.10

* Thu Jun 02 2016 daviddavid <daviddavid> 3.0.2-9.mga6
+ Revision: 1019795
- return back wxgtk built with gtk2 (fixes some gtk3 regressions)

* Wed May 25 2016 daviddavid <daviddavid> 3.0.2-8.mga6
+ Revision: 1018261
- add upstream patch to fix window sizing issue with gtk 3.19+
  * https://github.com/wxWidgets/wxWidgets/commit/9fea81c069f9d803d79c4ce82f87a00a6e10b490
+ luigiwalser <luigiwalser>
- back to webkit1 for now
- try building with webkit2

* Fri Jan 08 2016 wally <wally> 3.0.2-7.mga6
+ Revision: 920622
- add patch (P4) from ustream to fix drawing checkbox and radiobutton in checked state with GTK+ >= 3.14
- add Mga patch (P5) to fix 'Gtk-WARNING **: State 0 for GtkButton 0x990b1e0 doesn't match state 128 set via gtk_style_context_set_state ()' flood in cmd line with GTK+ 3.19

* Wed Aug 26 2015 fwang <fwang> 3.0.2-6.mga6
+ Revision: 869528
- rebuild for gcc5

* Fri Aug 14 2015 ycantin <ycantin> 3.0.2-5.mga6
+ Revision: 864678
- Use builtin regex to enable wxRE_ADVANCED

* Sun Aug 02 2015 wally <wally> 3.0.2-4.mga6
+ Revision: 860799
- increase update-alternatives priority for wx-config and wxrc so they'll be used as a default when also older wxgtk2.8-devel is installed

* Tue Jul 21 2015 philippem <philippem> 3.0.2-3.mga6
+ Revision: 856002
- build with gtk3

* Tue Mar 17 2015 guillomovitch <guillomovitch> 3.0.2-2.mga6
+ Revision: 818725
- disable utf8 usage for strings, fixing a compilation issue with another software (veracrypt)

* Wed Mar 04 2015 luigiwalser <luigiwalser> 3.0.2-1.mga5
+ Revision: 817651
- 3.0.2
- enable libmspack

* Wed Oct 15 2014 umeabot <umeabot> 3.0.1-3.mga5
+ Revision: 750323
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.0.1-2.mga5
+ Revision: 690382
- Mageia 5 Mass Rebuild

* Wed Jun 18 2014 wally <wally> 3.0.1-1.mga5
+ Revision: 637995
- new version 3.0.1

* Wed Feb 05 2014 fwang <fwang> 3.0.0-2.mga5
+ Revision: 583484
- add virtual provides
- don't override Werror_cflags

* Wed Feb 05 2014 fwang <fwang> 3.0.0-1.mga5
+ Revision: 583461
- update file list
- use macro
- fix link
- update filename
- update config suffix
- new version 3.0.0

* Tue Oct 22 2013 umeabot <umeabot> 2.9.5-2.mga4
+ Revision: 542368
- Mageia 4 Mass Rebuild
+ wally <wally>
- loosen requires

* Mon Oct 14 2013 wally <wally> 2.9.5-1.mga4
+ Revision: 497442
- new version 2.9.5
- add update-alternatives support for wx-config and wxrc
- add patch to make pkgs parallel installable with wxgtk2.8 (originally from Gentoo)
- rename source pkg as wxgtk for future stable ones

* Sun Jun 02 2013 fwang <fwang> 2.8.12-11.mga4
+ Revision: 434699
- rebuild for new libpng

* Mon Jan 14 2013 umeabot <umeabot> 2.8.12-10.mga3
+ Revision: 385897
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 24 2012 fwang <fwang> 2.8.12-9.mga3
+ Revision: 200605
- move to correct section
- fix wrong symlink
- drop old packages
- only build unicode flavour
- cleanup messed up multiarch programs

* Fri Jan 20 2012 fwang <fwang> 2.8.12-7.mga2
+ Revision: 198660
- do not promote permissive in cnfig
- drop permissive build, as it is default to off by upstream

* Fri Dec 23 2011 fwang <fwang> 2.8.12-6.mga2
+ Revision: 186478
- rebuild for new libtiff

* Tue Dec 13 2011 wally <wally> 2.8.12-5.mga2
+ Revision: 181328
- fix lib names
- fix and clean provides
- clean .spec a bit
- update configure options to fix build and to build more libs
- drop old conflicts
- clean and sort BRs

* Sun Sep 11 2011 fwang <fwang> 2.8.12-4.mga2
+ Revision: 142256
- rebuild for new libpng
+ ahmad <ahmad>
- Change the BR to pkgconfig BR style
- Drop redundant BR libGConf2-devel
- Don't promote LDFLAGS in wx-config (fwang)
- Build with --enable-catch_segvs. The only pro I could find for disabling it
  is that it interferes with ABRT support[1], since we don't have ABRT support
  (either proper integration in the distro nor server side (bugzilla)) we can
  enable it for the time being. This should (fix mga#2232).
  [1] http://comments.gmane.org/gmane.linux.redhat.fedora.devel/135119

* Tue Jun 21 2011 ahmad <ahmad> 2.8.12-1.mga2
+ Revision: 111191
- Update to 2.8.12
- fix linking, and drop _disable_ld_no_undefined
- disable rpath for the unicode build too

* Fri Feb 25 2011 ahmad <ahmad> 2.8.11-4.mga1
+ Revision: 59942
- add more BR (Fedora)
- configure with --disable-rpath (Fedora)

* Sun Jan 16 2011 ahmad <ahmad> 2.8.11-3.mga1
+ Revision: 19943
- imported package wxgtk2.8

